@@ -1,5 +1,5 @@
 package Log::Log4perl::Tiny;
-$Log::Log4perl::Tiny::VERSION = '1.2.9';
+$Log::Log4perl::Tiny::VERSION = '1.2.10';
 # ABSTRACT: mimic Log::Log4perl in one single module
 
 use warnings;
@@ -575,7 +575,64 @@ Log::Log4perl::Tiny - mimic Log::Log4perl in one single module
 
 =head1 VERSION
 
-version 1.2.9
+version 1.2.10
+
+=head1 SYNOPSIS
+
+   use Log::Log4perl::Tiny qw( :easy );
+   Log::Log4perl->easy_init({
+      file   => '/var/log/something.log',
+      layout => '[%d] [%-5P:%-5p] %m%n',
+      level  => $INFO,
+   });
+
+   WARN 'something weird happened';
+   INFO 'just doing it';
+   DEBUG 'this does not get printed at $INFO level';
+
+   # LOGLEVEL isn't in Log::Log4perl, but might come handy
+   LOGLEVEL($DEBUG);   # enable debugging for small section
+   # otherwise, "get_logger()->level($DEBUG)", see below
+
+   DEBUG 'now this gets printed';
+   LOGLEVEL($INFO);    # disable debugging again
+   DEBUG 'skipped, again';
+   DEBUG 'complex evaluation value:', sub { 
+      # evaluation skipped if log level filters DEBUG out
+   };
+
+   # Object-oriented interface is available as well
+   my $logger = get_logger();
+   $logger->level($DEBUG);   # enable debugging for small section
+   $logger->debug('whatever you want');
+   $logger->level($INFO);    # disable debugging again
+
+   # All stealth loggers are available
+   LOGCONFESS 'I cannot accept this, for a whole stack of reasons!';
+
+   # Want to change layout?
+   $logger->layout('[%d %p] %m%n');
+   # or, equivalently
+   $logger->format('[%d %p] %m%n');
+
+   # Want to send the output somewhere else?
+   use IO::Handle;
+   open my $fh, '>>', '/path/to/new.log';
+   $fh->autoflush();
+   $logger->fh($fh);
+
+   # Want to multiplex output to different channels?
+   $logger->fh(
+      build_channels(
+         fh          => \*STDERR,
+         file_create => '/var/log/lastrun.log',
+         file_append => '/var/log/overall.log',
+      )
+   );
+
+   # Want to handle the output message by yourself?
+   my @queue; # e.g. all log messages will be put here
+   $logger->fh(sub { push @queue, $_[0] });
 
 =head1 DESCRIPTION
 
@@ -877,6 +934,16 @@ C<$Log::Log4perl::LOGEXIT_CODE>, or set a code with
 C<logexit_code()> - but you have to wait to read something about the
 object-oriented interface before doing this!
 
+As indicated, functions L</LOGWARN>, L</LOGDIE>, L</LOGCARP>,
+L</LOGCLUCK>, L</LOGCROACK>, and L</LOGCONFESS> (as well as their
+lowercase counterparts called as object methods) both emit the log
+message on the normal output channel for Log::Log4perl::Tiny and call
+the respective function. This might not be what you want in the default
+case where the output channel is standard error, because you will end up
+with duplicate error messages. You can avoid the call to the
+I<canonical> function setting import option C<:no_extra_logdie_message>,
+in line with what L<Log::Log4perl> provides.
+
 There is also one additional stealth function that L<Log::Log4perl>
 misses but that I think is of the outmoste importance: C<LOGLEVEL>, to
 set the log level threshold for printing. If you want to be 100%
@@ -939,63 +1006,6 @@ is fixed. (Thanks to C<Log::Tiny> for the cool trick of how to handle
 the C<printf>-like string, which is probably mutuated from
 C<Log::Log4perl> itself according to the comments).
 
-=head1 SYNOPSYS
-
-   use Log::Log4perl::Tiny qw( :easy );
-   Log::Log4perl->easy_init({
-      file   => '/var/log/something.log',
-      layout => '[%d] [%-5P:%-5p] %m%n',
-      level  => $INFO,
-   });
-
-   WARN 'something weird happened';
-   INFO 'just doing it';
-   DEBUG 'this does not get printed at $INFO level';
-
-   # LOGLEVEL isn't in Log::Log4perl, but might come handy
-   LOGLEVEL($DEBUG);   # enable debugging for small section
-   # otherwise, "get_logger()->level($DEBUG)", see below
-
-   DEBUG 'now this gets printed';
-   LOGLEVEL($INFO);    # disable debugging again
-   DEBUG 'skipped, again';
-   DEBUG 'complex evaluation value:', sub { 
-      # evaluation skipped if log level filters DEBUG out
-   };
-
-   # Object-oriented interface is available as well
-   my $logger = get_logger();
-   $logger->level($DEBUG);   # enable debugging for small section
-   $logger->debug('whatever you want');
-   $logger->level($INFO);    # disable debugging again
-
-   # All stealth loggers are available
-   LOGCONFESS 'I cannot accept this, for a whole stack of reasons!';
-
-   # Want to change layout?
-   $logger->layout('[%d %p] %m%n');
-   # or, equivalently
-   $logger->format('[%d %p] %m%n');
-
-   # Want to send the output somewhere else?
-   use IO::Handle;
-   open my $fh, '>>', '/path/to/new.log';
-   $fh->autoflush();
-   $logger->fh($fh);
-
-   # Want to multiplex output to different channels?
-   $logger->fh(
-      build_channels(
-         fh          => \*STDERR,
-         file_create => '/var/log/lastrun.log',
-         file_append => '/var/log/overall.log',
-      )
-   );
-
-   # Want to handle the output message by yourself?
-   my @queue; # e.g. all log messages will be put here
-   $logger->fh(sub { push @queue, $_[0] });
-
 =head1 INTERFACE 
 
 You have two interfaces at your disposal, the functional one (with all
